/***************************************************************************
                          rfiledxf.h  -  description
                             -------------------
    begin                : Mon Sep 27 1999
    copyright            : (C) 1999 by Andreas Mustun
    email                : andrew@ribbonsoft.com
 ***************************************************************************/

/****************************************************************************
** rfiledxf.h 1998/08/24 A. Mustun RibbonSoft 
**
** Copyright (C) 1998 RibbonSoft.  All rights reserved.
**
*****************************************************************************/

#ifndef RFILEDXF_H
#define RFILEDXF_H

#include "rfilebase.h"

#include "rprgdef.h"

class RGraphic;

class RFileDxf : public RFileBase
{
public:
  RFileDxf(const QString& _name, RGraphic* _graphic);
  ~RFileDxf();

  bool load(bool add=false);
  bool readFromBuffer(bool add=false);

  bool save();
    
private:
  RGraphic* graphic;
  int       numElements;
  
};


#endif

// EOF


